@@ -22,6 +22,9 @@ class TriplesImport:
             pulsar_client, topic = queue, schema = Triples
         )
 
+    async def start(self):
+        await self.publisher.start()
+
     async def destroy(self):
         self.running.stop()
 
