@@ -1,7 +1,6 @@
 
 import asyncio
 from aiohttp import web
-import uuid
 import logging
 
 logger = logging.getLogger("endpoint")
@@ -47,10 +46,8 @@ class VariableEndpoint:
 
             data = await request.json()
 
-            print(data)
-
             async def responder(x, fin):
-                print(x)
+                pass
 
             resp = await self.dispatcher.process(
                 data, responder, request.match_info
